@@ -10,7 +10,7 @@ import asyncio
 import json
 import logging
 from pathlib import Path
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, Literal
 
 import click
 import requests
@@ -20,11 +20,21 @@ from rich.pretty import pretty_repr
 
 from anta.cli.console import console
 from anta.cli.get.utils import inventory_output_options
-from anta.cli.utils import ExitCode, inventory_options
+from anta.cli.utils import ExitCode, catalog_options, inventory_options
 
-from .utils import create_inventory_from_ansible, create_inventory_from_cvp, explore_package, get_cv_token
+from .utils import (
+    _explore_package,
+    _filter_tests_via_catalog,
+    _get_unique_commands,
+    _print_commands,
+    create_inventory_from_ansible,
+    create_inventory_from_cvp,
+    get_cv_token,
+    print_tests,
+)
 
 if TYPE_CHECKING:
+    from anta.catalog import AntaCatalog
     from anta.inventory import AntaInventory
 
 logger = logging.getLogger(__name__)
@@ -147,14 +157,53 @@ def tags(inventory: AntaInventory, **kwargs: Any) -> None:
 def tests(ctx: click.Context, module: str, test: str | None, *, short: bool, count: bool) -> None:
     """Show all builtin ANTA tests with an example output retrieved from each test documentation."""
     try:
-        tests_found = explore_package(module, test_name=test, short=short, count=count)
-        if tests_found == 0:
+        tests_found = _explore_package(module, test_name=test, short=short, count=count)
+        if len(tests_found) == 0:
             console.print(f"""No test {f"'{test}' " if test else ""}found in '{module}'.""")
         elif count:
-            if tests_found == 1:
+            if len(tests_found) == 1:
                 console.print(f"There is 1 test available in '{module}'.")
             else:
-                console.print(f"There are {tests_found} tests available in '{module}'.")
+                console.print(f"There are {len(tests_found)} tests available in '{module}'.")
+        else:
+            print_tests(tests_found, short=short)
+    except ValueError as e:
+        logger.error(str(e))
+        ctx.exit(ExitCode.USAGE_ERROR)
+
+
+@click.command
+@click.pass_context
+@click.option("--module", help="Filter commands by module name.", default="anta.tests", show_default=True)
+@click.option("--test", help="Filter by specific test name. If module is specified, searches only within that module.", type=str)
+@catalog_options(required=False)
+@click.option("--unique", help="Print only the unique commands.", is_flag=True, default=False)
+def commands(
+    ctx: click.Context,
+    module: str,
+    test: str | None,
+    catalog: AntaCatalog,
+    catalog_format: Literal["yaml", "json"] = "yaml",
+    *,
+    unique: bool,
+) -> None:
+    """Print all EOS commands used by the selected ANTA tests.
+
+    It can be filtered by module, test or using a catalog.
+    If no filter is given, all built-in ANTA tests commands are retrieved.
+    """
+    # TODO: implement catalog and catalog format
+    try:
+        tests_found = _explore_package(module, test_name=test)
+        if catalog:
+            tests_found = _filter_tests_via_catalog(tests_found, catalog)
+        if len(tests_found) == 0:
+            console.print(f"""No test {f"'{test}' " if test else ""}found in '{module}'{f" for catalog '{catalog.filename}'" if catalog else ""}.""")
+        if unique:
+            for command in _get_unique_commands(tests_found):
+                console.print(command)
+        else:
+            _print_commands(tests_found)
     except ValueError as e:
         logger.error(str(e))
         ctx.exit(ExitCode.USAGE_ERROR)
