@@ -14,13 +14,14 @@ import rich
 from rich.panel import Panel
 from rich.progress import BarColumn, MofNCompleteColumn, Progress, SpinnerColumn, TextColumn, TimeElapsedColumn, TimeRemainingColumn
 
+from anta import __version__ as anta_version
+from anta._runner import AntaRunContext, AntaRunFilters, AntaRunner
 from anta.cli.console import console
 from anta.cli.utils import ExitCode
 from anta.models import AntaTest
 from anta.reporter import ReportJinja, ReportTable
 from anta.reporter.csv_reporter import ReportCsv
 from anta.reporter.md_reporter import MDReportGenerator
-from anta.runner import main
 
 if TYPE_CHECKING:
     import pathlib
@@ -34,7 +35,7 @@ if TYPE_CHECKING:
 logger = logging.getLogger(__name__)
 
 
-def run_tests(ctx: click.Context) -> None:
+def run_tests(ctx: click.Context) -> AntaRunContext:
     """Run the tests."""
     # Digging up the parameters from the parent context
     if ctx.parent is None:
@@ -50,21 +51,19 @@ def run_tests(ctx: click.Context) -> None:
 
     print_settings(inventory, catalog)
     with anta_progress_bar() as AntaTest.progress:
-        # TODO: Use AntaRunner directly in ANTA v2.0.0
-        asyncio.run(
-            main(
-                ctx.obj["result_manager"],
-                inventory,
-                catalog,
-                tags=tags,
-                devices=set(device) if device else None,
-                tests=set(test) if test else None,
-                dry_run=dry_run,
-            )
+        runner = AntaRunner()
+        filters = AntaRunFilters(
+            devices=set(device) if device else None,
+            tests=set(test) if test else None,
+            tags=tags,
         )
+        run_ctx = asyncio.run(runner.run(inventory=inventory, catalog=catalog, result_manager=ctx.obj["result_manager"], filters=filters, dry_run=dry_run))
+
     if dry_run:
         ctx.exit()
 
+    return run_ctx
+
 
 def _get_result_manager(ctx: click.Context, *, apply_hide_filter: bool = True) -> ResultManager:
     """Get a ResultManager instance based on Click context."""
@@ -149,7 +148,7 @@ def save_to_csv(ctx: click.Context, csv_file: pathlib.Path) -> None:
         ctx.exit(ExitCode.USAGE_ERROR)
 
 
-def save_markdown_report(ctx: click.Context, md_output: pathlib.Path) -> None:
+def save_markdown_report(ctx: click.Context, md_output: pathlib.Path, run_context: AntaRunContext | None = None) -> None:
     """Save the markdown report to a file.
 
     Parameters
@@ -158,12 +157,39 @@ def save_markdown_report(ctx: click.Context, md_output: pathlib.Path) -> None:
         Click context containing the result manager.
     md_output
         Path to save the markdown report.
+    run_context
+        Optional `AntaRunContext` instance returned from `AntaRunner.run()`.
+        If provided, a `Run Overview` section will be generated in the report including the run context information.
     """
+    extra_data = None
+    if run_context is not None:
+        active_filters_dict = {}
+        if run_context.filters.tags:
+            active_filters_dict["tags"] = sorted(run_context.filters.tags)
+        if run_context.filters.tests:
+            active_filters_dict["tests"] = sorted(run_context.filters.tests)
+        if run_context.filters.devices:
+            active_filters_dict["devices"] = sorted(run_context.filters.devices)
+
+        extra_data = {
+            "anta_version": anta_version,
+            "test_execution_start_time": run_context.start_time,
+            "test_execution_end_time": run_context.end_time,
+            "total_duration": run_context.duration,
+            "total_devices_in_inventory": run_context.total_devices_in_inventory,
+            "devices_unreachable_at_setup": run_context.devices_unreachable_at_setup,
+            "devices_filtered_at_setup": run_context.devices_filtered_at_setup,
+            "filters_applied": active_filters_dict if active_filters_dict else None,
+        }
+
+        if run_context.warnings_at_setup:
+            extra_data["warnings_at_setup"] = run_context.warnings_at_setup
+
     try:
         manager = _get_result_manager(ctx, apply_hide_filter=False).sort(["name", "categories", "test"])
         filtered_manager = _get_result_manager(ctx, apply_hide_filter=True).sort(["name", "categories", "test"])
         sections = [(section, filtered_manager) if section.__name__ == "TestResults" else (section, manager) for section in MDReportGenerator.DEFAULT_SECTIONS]
-        MDReportGenerator.generate_sections(md_filename=md_output, sections=sections)
+        MDReportGenerator.generate_sections(md_filename=md_output, sections=sections, extra_data=extra_data)
         console.print(f"Markdown report saved to {md_output} ✅", style="cyan")
     except OSError:
         console.print(f"Failed to save Markdown report to {md_output} ❌", style="cyan")
