@@ -21,7 +21,6 @@ from .models import CategoryStats, DeviceStats, TestStats
 logger = logging.getLogger(__name__)
 
 
-# pylint: disable=too-many-instance-attributes
 class ResultManager:
     """Manager of ANTA Results.
 
@@ -253,7 +252,7 @@ class ResultManager:
             if not set(sort_by).issubset(set(accepted_fields)):
                 msg = f"Invalid sort_by fields: {sort_by}. Accepted fields are: {list(accepted_fields)}"
                 raise ValueError(msg)
-            results = sorted(results, key=lambda result: [getattr(result, field) for field in sort_by])
+            results = sorted(results, key=lambda result: [getattr(result, field) or "" for field in sort_by])
 
         return results
 
@@ -295,7 +294,7 @@ class ResultManager:
         if not set(sort_by).issubset(set(accepted_fields)):
             msg = f"Invalid sort_by fields: {sort_by}. Accepted fields are: {list(accepted_fields)}"
             raise ValueError(msg)
-        self._result_entries.sort(key=lambda result: [getattr(result, field) for field in sort_by])
+        self._result_entries.sort(key=lambda result: [getattr(result, field) or "" for field in sort_by])
         return self
 
     def filter(self, hide: set[AntaTestStatus]) -> ResultManager:
@@ -316,6 +315,25 @@ class ResultManager:
         manager.results = self.get_results(possible_statuses - hide)
         return manager
 
+    @classmethod
+    def merge_results(cls, results_managers: list[ResultManager]) -> ResultManager:
+        """Merge multiple ResultManager instances.
+
+        Parameters
+        ----------
+        results_managers
+            A list of ResultManager instances to merge.
+
+        Returns
+        -------
+        ResultManager
+            A new ResultManager instance containing the results of all the input ResultManagers.
+        """
+        combined_results = list(chain(*(rm.results for rm in results_managers)))
+        merged_manager = cls()
+        merged_manager.results = combined_results
+        return merged_manager
+
     @deprecated("This method is deprecated. This will be removed in ANTA v2.0.0.", category=DeprecationWarning)
     def filter_by_tests(self, tests: set[str]) -> ResultManager:
         """Get a filtered ResultManager that only contains specific tests.
