@@ -12,7 +12,9 @@ from __future__ import annotations
 
 import re
 from ipaddress import IPv4Address
-from typing import TYPE_CHECKING, ClassVar
+from typing import TYPE_CHECKING, Annotated, ClassVar, Literal
+
+from pydantic import Field
 
 from anta.custom_types import LogSeverityLevel
 from anta.input_models.logging import LoggingQuery
@@ -423,7 +425,28 @@ class VerifyLoggingErrors(AntaTest):
     """
 
     categories: ClassVar[list[str]] = ["logging"]
-    commands: ClassVar[list[AntaCommand | AntaTemplate]] = [AntaCommand(command="show logging threshold errors", ofmt="text")]
+    commands: ClassVar[list[AntaCommand | AntaTemplate]] = [AntaTemplate(template="show logging threshold errors {log_history_depth}", ofmt="text")]
+
+    class Input(AntaTest.Input):
+        """Input model for the VerifyLoggingErrors test."""
+
+        last_number_time_units: Annotated[int, Field(ge=1, le=9999)] | None = None
+        """Number of time units to look in the logging buffers.
+
+        The actual duration is determined based on the selected `time_unit` (e.g. 5 days, 10 minutes)."""
+        time_unit: Literal["days", "hours", "minutes", "seconds"] = "days"
+        """Unit of time to be used with `last_number_time_units`."""
+
+    def render(self, template: AntaTemplate) -> list[AntaCommand]:
+        """Render the template for log history depth in the input."""
+        commands: list[AntaCommand] = []
+        log_history_depth: str = ""
+
+        if self.inputs.last_number_time_units:
+            log_history_depth = f"last {self.inputs.last_number_time_units} {self.inputs.time_unit}"
+        commands.append(template.render(log_history_depth=log_history_depth))
+
+        return commands
 
     @AntaTest.anta_test
     def test(self) -> None:
@@ -437,12 +460,17 @@ class VerifyLoggingErrors(AntaTest):
 
 
 class VerifyLoggingEntries(AntaTest):
-    """Verifies that the expected log string is present in the last specified log messages.
+    """Verifies that log strings are present or absent in the logging buffer.
 
     Expected Results
     ----------------
-    * Success: The test will pass if the expected log string for the mentioned severity level is present in the last specified log messages.
-    * Failure: The test will fail if the specified log string is not present in the last specified log messages.
+    * Success:
+        - If `fail_on_match` is `False` (default): the test will pass if all specified patterns are found in the log output.
+        - If `fail_on_match` is `True`: the test will pass if none of the specified patterns are found in the log output.
+
+    * Failure:
+        - If `fail_on_match` is `False`: the test will fail if any of the specified patterns are missing from the log output.
+        - If `fail_on_match` is `True`: the test will fail if any of the specified patterns are found in the log output.
 
     Examples
     --------
@@ -453,16 +481,18 @@ class VerifyLoggingEntries(AntaTest):
             - regex_match: ".*ACCOUNTING-5-EXEC: cvpadmin ssh.*"
               last_number_messages: 30
               severity_level: alerts
-            - regex_match: ".*SPANTREE-6-INTERFACE_ADD:.*"
-              last_number_messages: 10
+            - regex_match:
+                - ".*SPANTREE-6-INTERFACE_ADD:.*"
+                - ".*ACCOUNTING-5-EXEC: cvpadmin ssh.*"
+              last_number_time_units: 3
+              time_unit: hours
               severity_level: critical
+              fail_on_match: True
     ```
     """
 
     categories: ClassVar[list[str]] = ["logging"]
-    commands: ClassVar[list[AntaCommand | AntaTemplate]] = [
-        AntaTemplate(template="show logging {last_number_messages} {severity_level}", ofmt="text", use_cache=False)
-    ]
+    commands: ClassVar[list[AntaCommand | AntaTemplate]] = [AntaTemplate(template="show logging {log_history_depth} {severity_level}", ofmt="text", use_cache=False)]
 
     class Input(AntaTest.Input):
         """Input model for the VerifyLoggingEntries test."""
@@ -471,8 +501,16 @@ class VerifyLoggingEntries(AntaTest):
         """List of logging entries and regex match."""
 
     def render(self, template: AntaTemplate) -> list[AntaCommand]:
-        """Render the template for last number messages and log severity level in the input."""
-        return [template.render(last_number_messages=entry.last_number_messages, severity_level=entry.severity_level) for entry in self.inputs.logging_entries]
+        """Render the template for log history depth and log severity level in the input."""
+        commands: list[AntaCommand] = []
+        for entry in self.inputs.logging_entries:
+            log_history_depth: str | int = ""
+            if entry.last_number_messages:
+                log_history_depth = entry.last_number_messages
+            elif entry.last_number_time_units:
+                log_history_depth = f"last {entry.last_number_time_units} {entry.time_unit}"
+            commands.append(template.render(log_history_depth=log_history_depth, severity_level=entry.severity_level))
+        return commands
 
     @AntaTest.anta_test
     def test(self) -> None:
@@ -480,7 +518,16 @@ class VerifyLoggingEntries(AntaTest):
         self.result.is_success()
         for command_output, logging_entry in zip(self.instance_commands, self.inputs.logging_entries):
             output = command_output.text_output
-            if not re.search(logging_entry.regex_match, output):
-                self.result.is_failure(
-                    f"Pattern: `{logging_entry.regex_match}` - Not found in last {logging_entry.last_number_messages} {logging_entry.severity_level} log entries"
-                )
+            log_history_depth = command_output.params.log_history_depth
+            patterns_to_check = logging_entry.regex_match if isinstance(logging_entry.regex_match, list) else [logging_entry.regex_match]
+
+            for pattern in patterns_to_check:
+                match_found = re.search(pattern, output)
+
+                # Fails if any of the regex patterns are found
+                if logging_entry.fail_on_match and match_found:
+                    self.result.is_failure(f"Unexpected Pattern: `{pattern}` - Found in last {log_history_depth} {logging_entry.severity_level} log entries")
+
+                # Fails if any of the regex patterns not found
+                if not logging_entry.fail_on_match and not match_found:
+                    self.result.is_failure(f"Pattern: `{pattern}` - Not found in last {log_history_depth} {logging_entry.severity_level} log entries")
