@@ -34,11 +34,29 @@ DATA: AntaUnitTestDataDict = {
         "inputs": {"profile": "test"},
         "expected": {"result": AntaTestStatus.SUCCESS},
     },
+    (VerifyTcamProfile, "failure-pmf-profiles-not-found"): {
+        "eos_data": [{"pmfProfiles": {}, "lastProgrammingStatus": {}}],
+        "inputs": {"profile": "test"},
+        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["No TCAM profile found"]},
+    },
     (VerifyTcamProfile, "failure"): {
         "eos_data": [
-            {"pmfProfiles": {"FixedSystem": {"config": "test", "configType": "System Profile", "status": "default", "mode": "tcam"}}, "lastProgrammingStatus": {}}
+            {
+                "pmfProfiles": {
+                    "Linecard3": {"config": "default", "configType": "System Profile", "status": "default", "mode": "tcam"},
+                    "Linecard4": {"config": "default", "configType": "System Profile", "status": "default", "mode": "tcam"},
+                    "FixedSystem": {"config": "default", "configType": "System Profile", "status": "default", "mode": "tcam"},
+                },
+            }
         ],
         "inputs": {"profile": "test"},
-        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["Incorrect profile running on device: default"]},
+        "expected": {
+            "result": AntaTestStatus.FAILURE,
+            "messages": [
+                "Linecard3 - Incorrect profile running on device - Expected: test Actual: default",
+                "Linecard4 - Incorrect profile running on device - Expected: test Actual: default",
+                "FixedSystem - Incorrect profile running on device - Expected: test Actual: default",
+            ],
+        },
     },
 }
