@@ -43,19 +43,19 @@ INIT_PARAMS: list[ParameterSet] = [
     pytest.param(
         {"host": None, "username": "anta", "password": "anta", "name": "test.anta.ninja"},
         None,
-        pytest.raises(ValueError, match="'host' is required to create an AsyncEOSDevice"),
+        pytest.raises(ValueError, match=r"'host' is required to create an AsyncEOSDevice"),
         id="host is None",
     ),
     pytest.param(
         {"host": "42.42.42.42", "username": None, "password": "anta", "name": "test.anta.ninja"},
         None,
-        pytest.raises(ValueError, match="'username' is required to instantiate device 'test.anta.ninja'"),
+        pytest.raises(ValueError, match=r"'username' is required to instantiate device 'test.anta.ninja'"),
         id="username is None",
     ),
     pytest.param(
         {"host": "42.42.42.42", "username": "anta", "password": None, "name": "test.anta.ninja"},
         None,
-        pytest.raises(ValueError, match="'password' is required to instantiate device 'test.anta.ninja'"),
+        pytest.raises(ValueError, match=r"'password' is required to instantiate device 'test.anta.ninja'"),
         id="password is None",
     ),
 ]
@@ -369,6 +369,23 @@ ASYNCEAPI_COLLECT_PARAMS: list[ParameterSet] = [
         {"output": None, "errors": ["Invalid input (privileged mode required)"]},
         id="asynceapi.EapiCommandError - requires privileges",
     ),
+    pytest.param(
+        {},
+        {
+            "command": "session peer-supervisor show file systems",
+            "patch_kwargs": {
+                "side_effect": EapiCommandError(
+                    passed=[],
+                    failed="session peer-supervisor show file systems",
+                    errors=[""],
+                    errmsg="CLI command 2 of 2 'session peer-supervisor show file systems' failed: could not run command",
+                    not_exec=[],
+                )
+            },
+        },
+        {"output": None, "errors": ["could not run command"]},
+        id="asynceapi.EapiCommandError - empty error list",
+    ),
     pytest.param(
         {},
         {"command": "show version", "patch_kwargs": {"side_effect": HTTPError("404")}},
